%global	pgadmin4instdir %{_libdir}/pgadmin4-%{version}
%global	pgadmin4homedir %{_localstatedir}/lib/pgadmin
%global	user_group_name pgadmin

Name:           pgadmin4
Version:        4.30
Release:        %mkrel 5
Summary:        Management tool for PostgreSQL
License:        PostgreSQL
Group:          Databases
URL:            https://www.pgadmin.org/
Source0:        https://download.postgresql.org/pub/pgadmin/%{name}/v%{version}/source/%{name}-%{version}.tar.gz
Source10:       https://download.postgresql.org/pub/pgadmin/%{name}/v%{version}/source/%{name}-%{version}.tar.gz.asc
# https://www.pgadmin.org/download/pgadmin-4-source-code/
Source11:       %{name}.keyring
Source1:        %{name}.conf
Source2:        %{name}.service.in
Source3:        %{name}.tmpfiles.d
Source4:        %{name}.desktop.in
Source5:        %{name}.config_local.py.in
Source6:        %{name}.qt.conf.in
Source7:        README.SUSE
Patch0:         use-os-makedirs.patch
Patch1:         fix-python3-crypto-call.patch
Patch2:         fix-python-lib.patch
# PATCH-FIX-UPSTREAM
Patch3:         0001-Fixed-an-issue-when-uploading-a-CSV.patch
Patch4:         0002-Ensure-that-upload-paths-are-children-of-the-storage-directory.patch
BuildRequires:  libmesagl-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(python3)
Requires:       webserver-base
Requires:       %{name}-web = %{version}
Requires:       python3 >= 3.3
Requires:       python3-email-validator
Requires:       python3-flask
Requires:       python3-flask-babelex
Requires:       python3-flask-gravatar
Requires:       python3-flask-login
Requires:       python3-flask-mail
Requires:       python3-flask-migrate
Requires:       python3-flask-paranoid
Requires:       python3-flask-security
Requires:       python3-flask-wtf
Requires:       python3-psutil
Requires:       python3-psycopg2
Requires:       python3-sqlparse
Requires:       python3-ldap3
Requires:       python3-simplejson
Requires:       python3-sshtunnel

%{?systemd_requires}

%description
pgAdmin 4 is a rewrite of the pgAdmin3 management tool for the
PostgreSQL database. It is written as a web application in Python,
using jQuery and Bootstrap for the client side processing and UI. On
the server side, Flask is being utilised.

This variant is a Qt-based runtime application intended to allow the
standalone use on a workstation - it is essentially a browser and
Python interpretor in one package which will be capable of hosting
the Python application and presenting it to the user as a desktop
application.

%package web
Summary:        Web package for pgAdmin4
Group:          Databases
Recommends:     python3-mod_wsgi
Suggests:       %{name}-doc
BuildArch:      noarch

%description web
pgAdmin 4 is a rewrite of the pgAdmin3 management tool for the
PostgreSQL database.

This package contains the required files to run pgAdmin4 as a web application

%package	doc
Summary:        Documentation for pgAdmin4
Group:          Documentation
BuildArch:      noarch

%description doc
pgAdmin 4 is a rewrite of the pgAdmin3 management tool for the
PostgreSQL database.

This package contains the documentation for pgadmin4.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%if %{?pkg_vcmp:%{pkg_vcmp python3-devel >= 3.8}}%{!?pkg_vcmp:0}
%patch2 -p1
%endif
sed -e 's@PYTHONSITELIB@%{python3_sitelib}@g' <%{SOURCE1} > %{name}.conf

cp %{S:7} .
# rpmlint
chmod -x docs/en_US/theme/pgadmin4/static/style.css
chmod -x docs/en_US/theme/pgadmin4/theme.conf

%build
cd runtime
export PYTHON_CONFIG=%{_bindir}/python3-config
export PYTHON_VERSION=%{python3_version}
export PGADMIN_PYTHON_DIR=%{_prefix}
export CFLAGS=%{RPM_OPT_FLAGS}
qmake-qt5 -o Makefile pgAdmin4.pro
make %{?_smp_mflags} VERBOSE=1

%install
cd runtime
install -d -m 755 %{buildroot}%{_docdir}/%{name}-docs/
cp -pr ../docs/* %{buildroot}%{_docdir}/%{name}-docs

install -d -m 755 %{buildroot}%{_bindir}
cp pgAdmin4 %{buildroot}%{_bindir}

install -d -m 755 %{buildroot}%{python3_sitelib}/pgadmin4-web
cp -pR ../web/* %{buildroot}%{python3_sitelib}/pgadmin4-web

install -d %{buildroot}%{_sysconfdir}/httpd/conf.d/
install -m 0644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}.conf

# Install desktop file
install -d %{buildroot}%{_datadir}/applications/
sed -e 's@PYTHONDIR@%{_bindir}/python3@g' -e 's@PYTHONSITELIB@%{python3_sitelib}@g' < %{SOURCE4} > %{buildroot}%{_datadir}/applications/%{name}.desktop

# Install config_local
install -m 0644 %{SOURCE5} %{buildroot}%{python3_sitelib}/%{name}-web/config_local.py

# Install QT conf file
# This directory will/may change in future releases.
install -d "%{buildroot}%{_sysconfdir}/xdg/pgadmin/"
sed -e 's@PYTHONSITELIB64@%{python3_sitearch}@g' -e 's@PYTHONSITELIB@%{python3_sitelib}@g'<%{SOURCE6} > "%{buildroot}%{_sysconfdir}/xdg/pgadmin/pgadmin4.conf"

# Install unit file/init script
# This is only for systemd supported distros:
install -d %{buildroot}%{_unitdir}
sed -e 's@PYTHONDIR@%{_bindir}/python3@g' -e 's@PYTHONSITELIB@%{python3_sitelib}@g' < %{SOURCE2} > %{buildroot}%{_unitdir}/%{name}.service

# ... and make a tmpfiles script to recreate it at reboot.
mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/%{name}.conf

cd %{buildroot}%{python3_sitelib}/%{name}-web
rm -f %{name}.db
echo "SERVER_MODE = False" > config_distro.py
echo "HTML_HELP = '%{_datadir}/doc/%{name}-docs/en_US/html/'" >> config_distro.py
chmod -x %{buildroot}%{_docdir}/%{name}-docs/en_US/images/*
rm %{buildroot}%{python3_sitelib}/%{name}-web/regression/.gitignore
rm %{buildroot}%{_docdir}/%{name}-docs/en_US/.gitignore
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcpgadmin4
%fdupes %{buildroot}%{_prefix}

install -d -m 0755 %{buildroot}%{_localstatedir}/log/pgadmin
install -d -m 0755 %{buildroot}%{pgadmin4homedir}
install -d -m 0755 %{buildroot}%{pgadmin4homedir}/storage
install -d -m 0700 %{buildroot}%{pgadmin4homedir}/sessions

%pre web
/usr/sbin/groupadd -r %{user_group_name} &>/dev/null || :
/usr/sbin/useradd  -g %{user_group_name} -s /bin/false -r -c "%{name}" -d %{pgadmin4homedir} %{user_group_name} &>/dev/null || :

%post web
%systemd_post %{name}.service
%_tmpfilescreate %{name}

%preun web
%systemd_preun %{name}.service

%postun web
# chown -R %{user_group_name}:%{user_group_name} %{pgadmin4homedir}
%systemd_postun_with_restart %{name}.service

%files
%doc README README.SUSE
%license LICENSE
%{_bindir}/pgAdmin4
%{_datadir}/applications/%{name}.desktop
%dir %{_sysconfdir}/xdg/pgadmin
%config %{_sysconfdir}/xdg/pgadmin/pgadmin4.conf

%files web
%dir %{python3_sitelib}/%{name}-web/
%{python3_sitelib}/%{name}-web/*
%dir %{_sysconfdir}/httpd
%dir %{_sysconfdir}/httpd/conf.d
%attr(-,apache,apache) %config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%{_sbindir}/rcpgadmin4
%ghost %dir %{_rundir}/%{name}
%attr(-,apache,apache) %dir %{pgadmin4homedir}
%attr(-,apache,apache) %dir %{pgadmin4homedir}/storage
%attr(700,apache,apache) %dir %{pgadmin4homedir}/sessions
%attr(-,apache,apache) %dir %{_localstatedir}/log/pgadmin

%files doc
%dir %{_docdir}/%{name}-docs
%doc %{_docdir}/%{name}-docs/*


%changelog
* Wed Jul 13 2022 papoteur <papoteur> 4.30-5.mga8
+ Revision: 1868692
- Disable the upgrade checking through another way (mag#30385)
- Disable update checking
- add requires psutil
- fix dependencies, directories and ownership
- new 4.30 with fixes (mga#30385)

* Thu Dec 17 2020 umeabot <umeabot> 4.22-3.mga8
+ Revision: 1659294
- Rebuild for new Qt5

* Mon Jun 29 2020 joequant <joequant> 4.22-2.mga8
+ Revision: 1600420
- fix typo

* Sun Jun 28 2020 joequant <joequant> 4.22-1.mga8
+ Revision: 1599778
- fix groups
- imported package pgadmin4

